@@ -282,6 +282,20 @@ class MainWindow(QtGui.QMainWindow):
         rank=converted[u'players'][0][u'rank'] 
         
         
+        #Zusätzliche stats
+        
+        
+
+        kassault=converted[u'players'][0][u'kits']['assault']['kills']
+        kdemo=converted[u'players'][0][u'kits']['demo']['kills']
+        ksupport=converted[u'players'][0][u'kits']['support']['kills']
+        krecon=converted[u'players'][0][u'kits']['recon']['kills']
+        dassault=converted[u'players'][0][u'kits']['assault']['deaths']
+        ddemo=converted[u'players'][0][u'kits']['demo']['deaths']
+        dsupport=converted[u'players'][0][u'kits']['support']['deaths']
+        drecon=converted[u'players'][0][u'kits']['recon']['deaths']
+ 		
+		
         
         #Calculations
         
@@ -336,10 +350,10 @@ class MainWindow(QtGui.QMainWindow):
                                   "General score: "+str(sc_general)+"\n"
                                   "Award score: "+str(sc_award)+"\n"
                                   "Objective score: "+str(sc_objective)+"\n"
-                                  "Engineer score: "+str(sc_demo)+"\n"
-                                  "Recon score: "+str(sc_recon)+"\n"
                                   "Assault score: "+str(sc_assault)+"\n"
+								  "Engineer score: "+str(sc_demo)+"\n"
                                   "Support score: "+str(sc_support)+"\n"
+                                  "Recon score: "+str(sc_recon)+"\n"								  
                                   "Vehicle score: "+str(sc_vehicle)+"\n"
                                   "Bonus score: "+str(sc_bonus)+"\n"
                                   "\nDetails:\n\n"
@@ -357,8 +371,25 @@ class MainWindow(QtGui.QMainWindow):
                                   "Accuracy: "+str(accuracy)+"\n"
                                   "Dogtags: "+str(dogt)+"\n"
                                   "Form: "+str(form)+"\n"
-                                  "Last update: "+str(date_lastupdate)+"\n")
-                    #"Engineer: "+str(sc_engineer)+"\n")
+                                  "Last update: "+str(date_lastupdate)+"\n"
+								  "Detailled class stats:\n\n"
+                                  "Assault: \n"
+                                  "Score: "+str(sc_assault)+"\n"
+                                  "Kills: "+str(kassault)+"\n"
+                                  "Deaths: "+str(dassault)+"\n\n"
+                                  "Engineer: \n"
+                                  "Score: "+str(sc_demo)+"\n"
+                                  "Kills: "+str(kdemo)+"\n"
+                                  "Deaths: "+str(ddemo)+"\n\n"
+                                  "Support: \n"
+                                  "Score: "+str(sc_support)+"\n"
+                                  "Kills: "+str(ksupport)+"\n"
+                                  "Deaths: "+str(dsupport)+"\n\n"
+                                  "Recon: \n"
+                                  "Score: "+str(sc_recon)+"\n"
+                                  "Kills: "+str(krecon)+"\n"
+                                  "Deaths: "+str(drecon)+"\n")
+                    
         
 
         
